"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = webpackNetlifyCmsConfig;

var _fs = require("fs");

var _path = require("path");

var _nuxt = require("nuxt");

var _webpack = require("webpack");

var _webpack2 = _interopRequireDefault(_webpack);

var _htmlWebpackPlugin = require("html-webpack-plugin");

var _htmlWebpackPlugin2 = _interopRequireDefault(_htmlWebpackPlugin);

var _extractTextWebpackPlugin = require("extract-text-webpack-plugin");

var _extractTextWebpackPlugin2 = _interopRequireDefault(_extractTextWebpackPlugin);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function webpackNetlifyCmsConfig(name, nuxtOptions, moduleConfig) {
  var ENTRY = (0, _path.resolve)(__dirname, "../lib/entry.js");
  var BUILD_DIR = moduleConfig.buildDir;
  var CHUNK_FILENAME = nuxtOptions.build.filenames.chunk;
  var PUBLIC_PATH = _nuxt.Utils.urlJoin(nuxtOptions.router.base, moduleConfig.adminPath);
  var EXTENSIONS_DIR = moduleConfig.extensionsDir;
  var PAGE_TITLE = moduleConfig.adminTitle;
  var PAGE_TEMPLATE = (0, _path.resolve)(__dirname, "../lib/template", "index.html");
  var REQUIRE_EXTENSIONS = (0, _fs.existsSync)(EXTENSIONS_DIR) ? true : false;

  var config = {
    name: name,
    entry: ENTRY,
    output: {
      path: BUILD_DIR,
      filename: "bundle.[chunkhash].js",
      chunkFilename: CHUNK_FILENAME,
      publicPath: PUBLIC_PATH
    },
    module: {
      loaders: [{ test: /\.css$/, loader: "style-loader!css-loader" }, {
        test: /\.(eot|svg|ttf|woff|woff2)$/,
        loader: "url-loader",
        options: {
          limit: 1000, // 1 KO
          name: "public/fonts/[name].[hash:7].[ext]"
        }
      }]
    },
    resolve: {
      alias: {
        extensions: EXTENSIONS_DIR
      }
    },
    plugins: [new _htmlWebpackPlugin2.default({
      title: PAGE_TITLE,
      filename: "index.html",
      template: PAGE_TEMPLATE,
      inject: true,
      chunksSortMode: "dependency"
    }), new _webpack2.default.DefinePlugin({
      REQUIRE_EXTENSIONS: REQUIRE_EXTENSIONS
    })]
  };

  // --------------------------------------
  // Production specific config
  // --------------------------------------
  if (!nuxtOptions.dev) {
    // CSS extraction
    config.plugins.push(new _extractTextWebpackPlugin2.default({
      filename: "style.[contenthash].css"
    }));
    // This is needed in webpack 2 for minify CSS
    config.plugins.push(new _webpack2.default.LoaderOptionsPlugin({
      minimize: true
    }));
  }

  return config;
}
/* eslint-disable import/no-extraneous-dependencies */
/* covered by nuxt */